/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _U2_CSV_COLUMN_CONFIGURATION_DIALOG_H_
#define _U2_CSV_COLUMN_CONFIGURATION_DIALOG_H_

#include <ui/ui_CSVColumnConfigurationDialog.h>
#include "CSVColumnConfiguration.h"

namespace U2 {

class CSVColumnConfigurationDialog : public QDialog, Ui_CSVColumnConfigurationDialog {
    Q_OBJECT
public:
    CSVColumnConfigurationDialog(QWidget* w, const ColumnConfig& config);

    ColumnConfig config;

public slots:
    virtual void accept();

private slots:
    virtual void sl_complMarkToggle(bool);
    virtual void sl_startToggle(bool);

};

} // namespace U2

#endif 
